@@ -55,7 +55,7 @@ abstract class HasOneOrMany extends Relation
     public function make(array $attributes = [])
     {
         return tap($this->related->newInstance($attributes), function ($instance) {
-            $instance->setAttribute($this->getForeignKeyName(), $this->getParentKey());
+            $this->setForeignAttributesForCreate($instance);
         });
     }
 
@@ -188,7 +188,7 @@ abstract class HasOneOrMany extends Relation
         if (is_null($instance = $this->find($id, $columns))) {
             $instance = $this->related->newInstance();
 
-            $instance->setAttribute($this->getForeignKeyName(), $this->getParentKey());
+            $this->setForeignAttributesForCreate($instance);
         }
 
         return $instance;
@@ -206,7 +206,7 @@ abstract class HasOneOrMany extends Relation
         if (is_null($instance = $this->where($attributes)->first())) {
             $instance = $this->related->newInstance($attributes + $values);
 
-            $instance->setAttribute($this->getForeignKeyName(), $this->getParentKey());
+            $this->setForeignAttributesForCreate($instance);
         }
 
         return $instance;
@@ -252,7 +252,7 @@ abstract class HasOneOrMany extends Relation
      */
     public function save(Model $model)
     {
-        $model->setAttribute($this->getForeignKeyName(), $this->getParentKey());
+        $this->setForeignAttributesForCreate($model);
 
         return $model->save() ? $model : false;
     }
@@ -281,7 +281,7 @@ abstract class HasOneOrMany extends Relation
     public function create(array $attributes = [])
     {
         return tap($this->related->newInstance($attributes), function ($instance) {
-            $instance->setAttribute($this->getForeignKeyName(), $this->getParentKey());
+            $this->setForeignAttributesForCreate($instance);
 
             $instance->save();
         });
@@ -304,6 +304,17 @@ abstract class HasOneOrMany extends Relation
         return $instances;
     }
 
+    /**
+     * Set the foreign ID for creating a related model.
+     *
+     * @param  \Illuminate\Database\Eloquent\Model  $model
+     * @return void
+     */
+    protected function setForeignAttributesForCreate(Model $model)
+    {
+        $model->setAttribute($this->getForeignKeyName(), $this->getParentKey());
+    }
+
     /**
      * Perform an update on all the related models.
      *
